==> mongodb_3.2.11.orig.tar.gz: mongodb-src-r3.2.11/src/mongo/db/exec/scoped_timer.h <==
/**
 *    Copyright (C) 2013-2014 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/disallow_copying.h"

namespace mongo {

/**
 * This class increments a counter by a rough estimate of the time elapsed since its
 * construction when it goes out of scope.
 */
class ScopedTimer {
    MONGO_DISALLOW_COPYING(ScopedTimer);

public:
    ScopedTimer(long long* counter);

    ~ScopedTimer();

private:
    // Default constructor disallowed.
    ScopedTimer();

    // Reference to the counter that we are incrementing with the elapsed time.
    long long* _counter;

    // Time at which the timer was constructed.
    long long _start;
};

}  // namespace mongo

==> mongodb_3.6.3.orig.tar.gz: mongodb-src-r3.6.3/src/mongo/db/exec/scoped_timer.h <==
/**
 *    Copyright (C) 2013-2014 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/disallow_copying.h"

#include "mongo/util/time_support.h"

namespace mongo {

class ClockSource;

/**
 * This class increments a counter by a rough estimate of the time elapsed since its
 * construction when it goes out of scope.
 */
class ScopedTimer {
    MONGO_DISALLOW_COPYING(ScopedTimer);

public:
    ScopedTimer(ClockSource* cs, long long* counter);

    ~ScopedTimer();

private:
    ClockSource* const _clock;
    // Reference to the counter that we are incrementing with the elapsed time.
    long long* _counter;

    // Time at which the timer was constructed.
    const Date_t _start;
};

}  // namespace mongo
